[Pkg-mozext-commits] [automatic-save-folder] 45/133: Add : Added an option to select the way the ASF box option is shown. It can now be minimized of hidden instead of just disabled (if the user choice is on Open instead of Save) Fix : prevent an exception if selecting the path list radio choice without any path selected first, by setting the default list choice on the first path.

David Prévot taffit at moszumanska.debian.org
Mon Apr 27 20:33:50 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch wip
in repository automatic-save-folder.

commit 270a6f4c0e7ceed7e4e808c7cf6d6897f3188062
Author: Cyan <Cyan at d0063192-6b2e-11de-89a9-0b20f3e2dceb>
Date:   Sat Jan 16 16:44:19 2010 +0000

    Add : Added an option to select the way the ASF box option is shown.
          It can now be minimized of hidden instead of just disabled (if the user
          choice is on Open instead of Save)
    Fix : prevent an exception if selecting the path list radio choice without any
          path selected first, by setting the default list choice on the first path.
    
    Attention : Italian locales are not updated on this revision, it should give an error if you open the preferences.
    
    git-svn-id: http://automatic-save-folder.googlecode.com/svn/trunk@45 d0063192-6b2e-11de-89a9-0b20f3e2dceb
---
 content/asf.js                         |   3 +
 content/asf_download.js                | 135 ++++++++++++++++++++++-----------
 content/options.xul                    |  13 +++-
 content/overlay_unknownContentType.xul |   6 +-
 defaults/preferences/asf.js            |   5 +-
 locale/en-US/about.dtd                 |  17 +++--
 locale/en-US/asf.dtd                   |   4 +
 locale/fr-FR/about.dtd                 |  15 ++--
 locale/fr-FR/asf.dtd                   |   4 +
 9 files changed, 141 insertions(+), 61 deletions(-)

diff --git a/content/asf.js b/content/asf.js
index 532aac7..d51052a 100644
--- a/content/asf.js
+++ b/content/asf.js
@@ -213,6 +213,7 @@ var automatic_save_folder = {
 	toggle_options: function () {  // called whenever the Options tab is selected
 		var instantApply = this.prefManager.getBoolPref("browser.preferences.instantApply");
 		var viewdloption = document.getElementById("asf-viewdloption");
+		var viewdloptionType = document.getElementById("asf-viewdloptionType");
 		var viewpathlist = document.getElementById("asf-viewpathselect");
 		var dialogaccept = document.getElementById("asf-dialogaccept");
 		var dialogacceptFiltered = document.getElementById("asf-dialogacceptFiltered");
@@ -255,11 +256,13 @@ var automatic_save_folder = {
 		// set the sub-D/L option to grey state
 		if (viewdloption.checked == false)
 		{
+			viewdloptionType.disabled = true;
 			viewpathlist.checked = false;
 			viewpathlist.disabled = true;
 		}
 		if (viewdloption.checked == true)
 		{
+			viewdloptionType.disabled = false;
 			viewpathlist.disabled = false;
 		}
 			
diff --git a/content/options.xul b/content/options.xul
index 277d49e..a98d124 100644
--- a/content/options.xul
+++ b/content/options.xul
@@ -28,6 +28,7 @@
 		<preference id="asf_keeptemp" name="extensions.asf.keeptemp" type="bool"/>
 		<preference id="asf_viewdloption" name="extensions.asf.viewdloption" type="bool"/>
 		<preference id="asf_viewpathselect" name="extensions.asf.viewpathselect" type="bool"/>
+		<preference id="asf_viewdloptionType" name="extensions.asf.viewdloptionType" type="int"/>
 		<preference id="asf_savetype" name="extensions.asf.savetype" type="int"/>
 		<preference id="asf_variablemode" name="extensions.asf.variablemode" type="bool"/>
 		<preference id="asf_dialogaccept" name="extensions.asf.dialogaccept" type="bool"/>
@@ -153,7 +154,17 @@
 			</hbox>
 			<checkbox id="asf-dialogaccept" preference="asf_dialogaccept" label="&asf.dialogaccept.bool;" oncommand="automatic_save_folder.toggle_options();"/>
 			<checkbox id="asf-dialogacceptFiltered" preference="asf_dialogacceptFiltered" label="&asf.dialogacceptFiltered.bool;"  tooltip="tooltip_dialogacceptFiltered" style="margin-left:25px;"/>
-			<checkbox id="asf-viewdloption" preference="asf_viewdloption" label="&asf.viewdloption.bool;" tooltip="tooltip_viewdloption" oncommand="automatic_save_folder.toggle_options();"/>
+			<hbox>
+				<checkbox id="asf-viewdloption" preference="asf_viewdloption" label="&asf.viewdloption.bool;" tooltip="tooltip_viewdloption" oncommand="automatic_save_folder.toggle_options();"/>
+				<menulist id="asf-viewdloptionType" preference="asf_viewdloptionType">
+					<menupopup>
+						<menuitem value="0" label="&asf.viewdloptionType0.label;"></menuitem>
+						<menuitem value="1" label="&asf.viewdloptionType1.label;"></menuitem>
+						<menuitem value="2" label="&asf.viewdloptionType2.label;"></menuitem>
+						<menuitem value="3" label="&asf.viewdloptionType3.label;"></menuitem>
+					</menupopup>
+				</menulist>
+			</hbox>
 			<checkbox id="asf-viewpathselect" preference="asf_viewpathselect"  label="&asf.viewpathselect.bool;" tooltip="tooltip_viewpathselect" style="margin-left:25px;white-space:pre-wrap"/>
 			<separator class="thin"/>
 			<checkbox id="asf-usecurrenturl" preference="asf_usecurrenturl" label="&asf.usecurrenturl.bool;"/>
diff --git a/content/overlay_unknownContentType.xul b/content/overlay_unknownContentType.xul
index eb2e57c..04789bb 100644
--- a/content/overlay_unknownContentType.xul
+++ b/content/overlay_unknownContentType.xul
@@ -15,8 +15,8 @@
 
 <vbox id="container"> 
 	<groupbox id="asf_dloptions" style="visibility: collapse;" flex="1">
-	<caption label="Automatic Save Folder"/>
-	<vbox>
+	<caption label="Automatic Save Folder" onclick="automatic_save_folder.toggle_dloptionsContent();"/>
+	<vbox id="asf_dloptions_content" style="visibility: visible;" >
 		<radiogroup id="asf_radio_savepath" align="left">
 				<radio id="asf_savefolder" value="0" width="280" crop="center" label="folder" class="small-indent" oncommand="automatic_save_folder.asf_toggle_savepath()"/>
 				<radio id="asf_lastpath" value="1" width="280" crop="center" label="folder" class="small-indent" oncommand="automatic_save_folder.asf_toggle_savepath()"/>
@@ -26,7 +26,7 @@
 						<description value="       "/><menulist id="asf_folder_list" width="280">
 						</menulist>
 					</hbox>
-				</vbox>				
+				</vbox>
 		</radiogroup>
 		<separator class="thin"/>
 		<hbox>
diff --git a/defaults/preferences/asf.js b/defaults/preferences/asf.js
index 8a6ceee..136de7f 100644
--- a/defaults/preferences/asf.js
+++ b/defaults/preferences/asf.js
@@ -1,6 +1,7 @@
- pref("extensions.asf.lastdir", true);
+ pref("extensions.asf.lastdir", true);
  pref("extensions.asf.keeptemp", true);
  pref("extensions.asf.viewdloption", false);
+ pref("extensions.asf.viewdloptionType", 0);
  pref("extensions.asf.viewpathselect", false);
  pref("extensions.asf.savetype", 0);
  pref("extensions.asf.defaultfolder", "");
@@ -19,4 +20,4 @@ pref("extensions.asf at mangaheart.org.description", "chrome://asf/locale/asf.prope
  pref("extensions.asf.userightclick", true);
  pref("extensions.asf.rightclicktimeout", true);
  pref("browser.download.saveLinkAsFilenameTimeout", 0); // set the default value to userpref.js to prevent main pref.js modification and restore default value on ASF uninstall.
- pref("extensions.asf.usecurrenturl", false);
\ No newline at end of file
+ pref("extensions.asf.usecurrenturl", false);
diff --git a/locale/en-US/about.dtd b/locale/en-US/about.dtd
index 2e347a1..afa666b 100644
--- a/locale/en-US/about.dtd
+++ b/locale/en-US/about.dtd
@@ -38,6 +38,7 @@
 + Add an option to automatically accept the "what would Firefox need to do with this file?" dialog windows (User requested). Use it with "Do not prompt the File explorer" option for even better efficiency.
 + Add an option to choose if you want to use the current website URL to verify the filters if the file's hosted domain doesn't match.
 + Display ASF icon on the add-ons manager even on disabled state, instead of the green puzzle piece (Firefox 3.6+)
++ Added a display option to show or hide the ASF option box, and added a link on the box name to show/hide the ASF option box content.
 * On the download dialog's drop-down menu: Sort path list alphabetically, remove duplicates, and made them working with dynamic renaming folder if option enabled.
 * Separated the "informations" tab in two other tabs "Help" and "About...".
 * Added tooltips instead of help text bellow each options (has some issues with Firefox2).
@@ -47,6 +48,7 @@
 ! Prevent an exception when "use current website URL" option is enabled and the address bar doesn't contain an URL.
   Happened with redirection download script and Firefox closing the new empty popup window, or using middle mouse-button click on a link.
 ! When using instantApply, the suggested filters weren't refreshed after closing the preference window.
+! Fixed a bug where sub-options were auto unchecked visually but not saved when using instantApply feature.
 
 Other updates :
 + Source code and revisions available on http://code.google.com/p/automatic-save-folder
@@ -152,10 +154,13 @@ And contributors:<br />
 <!ENTITY about.bugreport.title "Bugs report">
 <!ENTITY about.bugreport.content "- Photonic, Martin">
 
-<!ENTITY about.translation.title "Translation">
-<!ENTITY about.translation.content "- English : Cyan.<br />
-- French : Cyan.<br />
-- Italian : Scognito.<br />
-- Babelzilla.org team and translators<br />
-- Correction by : Goofy, Haynee, Narayan.<br />">
+<!ENTITY about.translation.title "Translations">
+<!ENTITY about.translation.content "- Independant translators and Babelzilla translation team: <br />
+- de : Michael Baer<br />
+- en-US : Cyan, Narayan<br />
+- es : RigoNet<br />
+- fr : Cyan, Goofy, Haynee<br />
+- id : dimassony<br />
+- it : Scognito.<br />
+- pt-BR : petruc<br />">
 
diff --git a/locale/en-US/asf.dtd b/locale/en-US/asf.dtd
index 543bcdb..92702b0 100644
--- a/locale/en-US/asf.dtd
+++ b/locale/en-US/asf.dtd
@@ -44,6 +44,10 @@
 <!ENTITY asf.dialogacceptFiltered.tooltip "Will not automatically accept the "What should Firefox do with this file" dialog windows if no filter matches.">
 <!ENTITY asf.viewdloption.bool "View options when downloading">
 <!ENTITY asf.viewdloption.tooltip "Allow you to see the last two destination folders and a link to add or edit the filters">
+<!ENTITY asf.viewdloptionType0.label "Always show">
+<!ENTITY asf.viewdloptionType1.label "Always minimize">
+<!ENTITY asf.viewdloptionType2.label "Minimize if disabled">
+<!ENTITY asf.viewdloptionType3.label "Hide if disabled">
 <!ENTITY asf.viewpathselect.bool "View the list of folders">
 <!ENTITY asf.viewpathselect.tooltip "Activate a drop-down menu with all the filter's path.">
 <!ENTITY asf.usecurrenturl.bool "Use the current website URL to verify the filter's domain if the hosted domain doesn't match.">
diff --git a/locale/fr-FR/about.dtd b/locale/fr-FR/about.dtd
index eddd6b9..861a97f 100644
--- a/locale/fr-FR/about.dtd
+++ b/locale/fr-FR/about.dtd
@@ -38,6 +38,7 @@
 + Ajout d'une option pour accepter automatiquement la fenêtre "Que doit faire Firefox de ce fichier ?". Utilisez la avec l'option de sauvegarde de Firefox "Enregistrer le fichier dans le dossier" pour une meilleure efficacité.
 + Ajout d'une option pour utiliser l'adresse du site courant avec le domaine du filtre si le domaine d'hébergement ne correspond pas.
 + Affichage de l'icône d'ASF dans le gestionnaire d'extensions même lorsque l'extension est désactivée, plutôt que la pièce de puzzle verte (Firefox 3.6+)
++ Ajout d'une option permettant de choisir le style d'affichage du groupe ASF, et ajout d'un lien sur le nom du groupe pour afficher/masquer son contenu.
 * Dans le menu déroulant sur la fenêtre de sauvegarde : Listing des dossiers par ordre alphabétique, suppression des doublons et nom de dossier dynamique si l'option est activée.
 * Séparation de l'onglet "informations" en deux onglets "Aide" et "À propos...".
 * Ajout d'infobulles à la place du texte explicatif sous les options (Quelques problèmes rencontrés avec Firefox2).
@@ -47,6 +48,7 @@
 ! Correction d'une exception lorsque l'option "Utiliser l'URL du site courant" est activé et que la barre d'adresse ne contient pas d'URL. 
   Se produisait généralement avec les script de redirection lorsque Firefox refermait le nouvel onglet vide, ou en cliquant sur un lien avec la molette de la souris.
 ! En utilisant l'option InstantApply, les filtres suggérés n'étaient pas rechargés à la fermeture de la fenêtre de préférences.
+! En utilisant l'option InstantApply, les sous-options qui se dé-sélectionnaient visuellement n'étaient pas enregistrées.
 
 Autres mises à jour :
 + Code source et révisions disponibles sur http://code.google.com/p/automatic-save-folder
@@ -153,9 +155,12 @@ Ainsi que les contributeurs :<br />
 <!ENTITY about.bugreport.content "- Photonic, Martin">
 
 <!ENTITY about.translation.title "Traductions">
-<!ENTITY about.translation.content "- Anglais : Cyan.<br />
-- Français : Cyan.<br />
-- Italien : Scognito.<br />
-- L'équipe et les traducteurs de Babelzilla.org<br />
-- Relecture et correction par : Goofy, Haynee, Narayan.<br />">
+<!ENTITY about.translation.content "- Traducteurs indépendants et l'équipe de traduction de Babelzilla : <br />
+- de : Michael Baer<br />
+- en-US : Cyan, Narayan<br />
+- es : RigoNet<br />
+- fr : Cyan, Goofy, Haynee<br />
+- id : dimassony<br />
+- it : Scognito.<br />
+- pt-BR : petruc<br />">
 
diff --git a/locale/fr-FR/asf.dtd b/locale/fr-FR/asf.dtd
index 07fc395..fa2ff78 100644
--- a/locale/fr-FR/asf.dtd
+++ b/locale/fr-FR/asf.dtd
@@ -44,6 +44,10 @@
 <!ENTITY asf.dialogacceptFiltered.tooltip "Ne valide pas automatiquement la fenêtre "Que doit faire Firefox avec ce fichier ?" si aucun filtre ne correspond.">
 <!ENTITY asf.viewdloption.bool "Afficher les options lors de l'enregistrement">
 <!ENTITY asf.viewdloption.tooltip "Permet de voir les deux derniers dossiers d'enregistrement et un lien pour éditer ou ajouter de nouveaux filtres.">
+<!ENTITY asf.viewdloptionType0.label "Toujours afficher">
+<!ENTITY asf.viewdloptionType1.label "Toujours réduire">
+<!ENTITY asf.viewdloptionType2.label "Réduire si désactivé">
+<!ENTITY asf.viewdloptionType3.label "Masquer si désactivé">
 <!ENTITY asf.viewpathselect.bool "Afficher la liste des filtres">
 <!ENTITY asf.viewpathselect.tooltip "Active le menu déroulant contenant le chemin de chaque filtre.">
 <!ENTITY asf.usecurrenturl.bool "Utiliser l'adresse du site courant pour comparer le domaine du filtre si le domaine d'hébergement ne correspond pas.">

diff --git a/content/asf_download.js b/content/asf_download.js
index 20fce5d..333c120 100644
--- a/content/asf_download.js
+++ b/content/asf_download.js
@@ -582,9 +582,10 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		var asf_radiogroup_pathselect = document.getElementById('asf_radiogroup_pathselect');
 		var asf_savefolder = document.getElementById('asf_savefolder');
 		var asf_folder_list = document.getElementById('asf_folder_list');
-		var asf_viewdloption = this.prefManager.getBoolPref("extensions.asf.viewdloption");	
-		var asf_viewpathselect = this.prefManager.getBoolPref("extensions.asf.viewpathselect");	
-		var useDownloadDir = this.prefManager.getBoolPref("browser.download.useDownloadDir");	
+		var asf_viewdloption = this.prefManager.getBoolPref("extensions.asf.viewdloption");
+		var asf_viewdloptionType = this.prefManager.getIntPref("extensions.asf.viewdloptionType");
+		var asf_viewpathselect = this.prefManager.getBoolPref("extensions.asf.viewpathselect");
+		var useDownloadDir = this.prefManager.getBoolPref("browser.download.useDownloadDir");
 		var folderList = this.prefManager.getIntPref("browser.download.folderList");
 		
 		var folder = "";
@@ -627,7 +628,7 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		
 		// check the lastpath, if different than current folder, then print radio choice to user
 		// so he can choose from found filters, or last used path.
-		var lastpath = this.loadUnicodeString("extensions.asf.lastpath");	
+		var lastpath = this.loadUnicodeString("extensions.asf.lastpath");
 		var asf_lastpath = document.getElementById('asf_lastpath');
 		
 		if ( (lastpath == folder) || (lastpath == "") )  // if same or empty (first time using ASF), do not show radio for lastpath choice
@@ -649,34 +650,51 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		
 		
 		//now, if the user checked the option to view asf on saving window, set it to visible
-		if(asf_viewdloption == true) asf_dloptions.style.visibility = "visible";
-		
-		//and last, if the user checked the option to view the path list on saving window, set it to visible
-		if((asf_viewpathselect == true) && (this.prefManager.getIntPref("extensions.asf.filtersNumber") > 0) )
+		if(asf_viewdloption == true) 
 		{
-			this.read_all_filterpath();
-			asf_radiogroup_pathselect.style.visibility = "visible";
-		}		
-		
-		// Check if the user use the "do not show file explorer" to automatically save to "desktop" or "downloads" and force the suggested path to those folders instead of found filters
-		if((useDownloadDir == true) && (folderList != 2)) // if set to desktop or Download
-		{
-			asf_radio_savepath.disabled = true;
-			asf_radiogroup_pathselect.disabled = true;
-			asf_folder_list.disabled = true;
-		}
-		else
-		{
-			asf_radio_savepath.disabled = false;
-			asf_radiogroup_pathselect.disabled = false;
-			asf_folder_list.disabled = false;
-		}		
+			if(asf_viewdloptionType == 0) asf_dloptions.style.visibility = "visible";
+			
+			if(asf_viewdloptionType == 1) 
+			{
+				asf_dloptions.style.visibility = "visible";
+				document.getElementById('asf_dloptions_content').style.visibility = "collapse";
+			}
+			
+			
+			
+			//and last, if the user checked the option to view the path list on saving window, set it to visible
+			if((asf_viewpathselect == true) && (this.prefManager.getIntPref("extensions.asf.filtersNumber") > 0) )
+			{
+				this.read_all_filterpath();
+				asf_radiogroup_pathselect.style.visibility = "visible";
+			}
+			
+			// Check if the user use the "do not show file explorer" to automatically save to "desktop" or "downloads" and force the suggested path to those folders instead of found filters
+			if((useDownloadDir == true) && (folderList != 2)) // if set to desktop or Download
+			{
+				asf_radio_savepath.disabled = true;
+				asf_radiogroup_pathselect.disabled = true;
+				asf_folder_list.disabled = true;
+			}
+			else
+			{
+				asf_radio_savepath.disabled = false;
+				asf_radiogroup_pathselect.disabled = false;
+				asf_folder_list.disabled = false;
+			}		
 
-		
-		// Set the max width to the size of the screen minus 200px. Added for Mac OSX users with long path choice.
-		// alert("first screen : " + screen.width + "x" + screen.height);
-		asf_dloptions.style.maxWidth = screen.width -200 +"px";
-		
+			
+			// Set the max width to the size of the screen minus 200px. Added for Mac OSX users with long path choice.
+			// alert("first screen : " + screen.width + "x" + screen.height);
+			asf_dloptions.style.maxWidth = screen.width -200 +"px";	
+		}
+	},
+	
+	
+	toggle_dloptionsContent: function(){
+		var asf_dloptions_content = document.getElementById('asf_dloptions_content').style.visibility;
+		document.getElementById('asf_dloptions_content').style.visibility = (asf_dloptions_content == "visible" ? "collapse" : "visible");
+		window.sizeToContent();
 	},
 	
 	
@@ -686,19 +704,47 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		var asf_radio_savepath = document.getElementById('asf_radio_savepath');
 		var asf_radiogroup_pathselect = document.getElementById('asf_radiogroup_pathselect');
 		var asf_folder_list = document.getElementById('asf_folder_list');
+		var asf_viewdloption = this.prefManager.getBoolPref("extensions.asf.viewdloption");	
+		var asf_viewdloptionType = this.prefManager.getIntPref("extensions.asf.viewdloptionType");
 		
+		// Workaround for bug 439323 (if call when not needed, dosen't work anymore)
+		// https://bugzilla.mozilla.org/show_bug.cgi?id=439323
+		var initialState = document.getElementById('asf_dloptions_content').style.visibility ;
 		
-		if(save) // if set to "save the file"
+		if (asf_viewdloption)
 		{
-			asf_radio_savepath.disabled = false;
-			asf_radiogroup_pathselect.disabled = false;
-			asf_folder_list.disabled = false;
-		}
-		else
-		{
-			asf_radio_savepath.disabled = true;
-			asf_radiogroup_pathselect.disabled = true;
-			asf_folder_list.disabled = true;
+			if(save) // if set to "save the file"
+			{
+				asf_radio_savepath.disabled = false;
+				asf_radiogroup_pathselect.disabled = false;
+				asf_folder_list.disabled = false;
+				if ((asf_viewdloptionType == 2) || (asf_viewdloptionType == 3))
+				{
+					document.getElementById('asf_dloptions').style.visibility = "visible";
+					document.getElementById('asf_dloptions_content').style.visibility = "visible";
+				}
+			}
+			else
+			{
+				asf_radio_savepath.disabled = true;
+				asf_radiogroup_pathselect.disabled = true;
+				asf_folder_list.disabled = true;
+				if (asf_viewdloptionType == 2) // minimize only
+				{
+					document.getElementById('asf_dloptions').style.visibility = "visible";
+					document.getElementById('asf_dloptions_content').style.visibility = "collapse";
+				}
+				if (asf_viewdloptionType == 3)
+				{
+					document.getElementById('asf_dloptions').style.visibility = "collapse";
+					document.getElementById('asf_dloptions_content').style.visibility = "collapse";
+				}
+			}
+			
+			if (initialState != document.getElementById('asf_dloptions_content').style.visibility)
+			{
+				window.sizeToContent();
+			}
 		}
 	},
 	
@@ -721,7 +767,7 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		var menupopup = document.createElementNS('http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul', 'menupopup');
 		
 		// Check if there is any filter in list
-		var nbrfilters = 	this.prefManager.getIntPref("extensions.asf.filtersNumber");		
+		var nbrfilters = 	this.prefManager.getIntPref("extensions.asf.filtersNumber");
 		var path = "";
 		
 		// Delete active list before repopulating (if editing filter and coming back to saving window)
@@ -750,6 +796,7 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		var pathlist_sort_alpha = true;   // let the user choose in next release.
 		if (pathlist_sort_alpha) pathlist.sort(); 
 		
+		
 		for (var i = 0; i < pathlist.length; i++)
 		{
 			path = pathlist[i];
@@ -764,8 +811,8 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 		
 		// Populate the path list into the menu
 		list.appendChild(menupopup);
-		
-	},	
+		list.selectedIndex = 0;
+	},
 	
 	
 	asf_toggle_savepath: function () {
@@ -886,7 +933,7 @@ Copyright (C) 2007-2009 Eric Cassar (Cyan).
 	);	
 	
 	addEventListener(
-	"click",		// After a click in the unknownContentType.xul, check if the user changed the saving option (save, open, etc.)
+	"command",		// After a click in the unknownContentType.xul, check if the user changed the saving option (save, open, etc.)
 	function(){ automatic_save_folder.check_uCTOption(); },  // Run main from automatic_save_folder to check the filters
 	false
 	);	
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/automatic-save-folder.git



More information about the Pkg-mozext-commits mailing list